<template>
    <div class="fullheight page-container">
        <div class="main-left">
            <div class="left-card1">
                <div class="card1-1">
                    <div class="card1-content">
                        <i class="icon-fengsu1 icon_size"></i>
                        <div class="font-style">平均风速</div>
                        <div
                            style="
                                font-size: 16px;
                                font-weight: bold;
                                margin-left: 20px;
                            "
                        >
                            {{ emsFactoryWinspdAvg }} m/s
                        </div>
                    </div>
                </div>
                <div class="card1-2">
                    <div class="card1-content">
                        <i class="icon-fengxiang2 icon_size"></i>
                        <div class="font-style">风向</div>
                        <div
                            style="
                                font-size: 16px;
                                font-weight: bold;
                                margin-left: 20px;
                            "
                        >
                            {{ winD }} °
                        </div>
                    </div>
                </div>
            </div>
            <div class="left-card2">
                <div class="chart">
                    <div class="title-style">平均风速(m/s）</div>
                    <div id="container1"></div>
                </div>
                <div class="chart">
                    <div class="title-style">风向（°）</div>
                    <div id="container2"></div>
                </div>
            </div>
            <div class="left-card3">
                <el-image
                    alt="尾流"
                    :src="photosUrl"
                    v-if="photosUrl"
                    :preview-src-list="srcList"
                ></el-image>
            </div>
        </div>
        <div class="main-right">
            <el-table
                :data="tableData"
                border
                stripe
                style="width: 100%"
                height="100%"
            >
                <el-table-column prop="code" label="机组编号" align="center">
                </el-table-column>
                <el-table-column prop="yaw" label="偏航角度" align="center">
                </el-table-column>
            </el-table>
        </div>
    </div>
</template>
<script>
import {Chart} from '@antv/g2'
import utils from '@/hotent-ui-util'
export default {
    name: 'group-control',
    data() {
        return {
            winD: '',
            tableData: [],
            chart1: null,
            chartData: [],
            chart2: null,
            chart2Data: [],
            accecptData: false,
            emsFactoryWinspdAvg: null,
            photosUrl: '', //require("@/assets/img/wake_21110.png"),
            srcList: [], //require('@/assets/img/wake_21110.png')
        }
    },
    created() {
        this.initData()
    },
    mounted() {
        this.initChart1()
        this.initChart2()
        this.accecptData = true
        this.$bus.$on('SCADAMsg', (data) => {
            if (this.accecptData) {
                this.changeData(data)
            }
        })
        this.$bus.$on('CQKZMsg', (data) => {
            if (this.accecptData) {
                this.changeCQKZData(data)
            }
        })
    },
    beforeDestroy() {
        // 切换页面 不再接收数据
        this.accecptData = false
        this.monthDataReady = false
        document.removeEventListener('visibilitychange', this.windowVisiable)
    },
    methods: {
        initData() {
            this.$http
                .post('${cssc}/biz/cqkz/fangroup/v1/getRecently')
                .then((res) => {
                    if (res.status == 200 && res.data && res.data.message) {
                        let data = JSON.parse(res.data.message)
                        this.changeCQKZData(data)
                    }
                })
        },
        changeCQKZData(data) {
            if (data.photosUrl) {
                this.srcList = []
                this.photosUrl = data.photosUrl
                this.srcList.push(data.photosUrl)
            }
            if (data.data) {
                this.tableData = data.data
            }
            this.winD = data.wind_direction ? data.wind_direction : null
            // 风速
            let newData = {
                date: parseInt(data.wind_time ? data.wind_time : null),
                winD: data.wind_direction ? data.wind_direction : null,
            }
            let fakeData = {
                date: parseInt(data.wind_time ? data.wind_time : null) - 60000,
                winD: data.wind_direction ? data.wind_direction : null,
            }

            // 更新
            if (data.wind_direction) {
                this.formatData(fakeData, 2)
                this.formatData(newData, 2)
            }
        },
        changeData(data) {
            // 平均风速
            this.emsFactoryWinspdAvg = data.wind.emsFactoryWinspdAvg
                ? data.wind.emsFactoryWinspdAvg.val
                : null

            // 风速
            let newData = {
                date: parseInt(data.time),
                winSpd: data.wind.emsFactoryWinspdAvg
                    ? data.wind.emsFactoryWinspdAvg.val
                    : null,
            }
            // 任意一个有就更新，两个都没有就不更新
            if (data.wind.emsFactoryWinspdAvg) {
                this.formatData(newData, 1)
            }
        },
        initChart1() {
            this.chart1 = new Chart({
                container: 'container1',
                autoFit: true,
                height: 300,
            })
            this.chart1.data(this.chartData)
            this.chart1.scale({
                date: {
                    alias: '时间',
                    type: 'time',
                    formatter: (value) => {
                        return utils.formatDate(value, 'time')
                    },
                },
                winSpd: {
                    alias: '平均风速(m/s)',
                    sync: true, // 将 pv 字段数值同 time 字段数值进行同步
                    nice: true,
                    min: 0,
                    max: 20,
                },
            })
            this.chart1.axis('date', {
                grid: null,
                label: {
                    style: {
                        fill: '#979ba4',
                    },
                },
                line: {
                    style: {
                        stroke: '#414959',
                    },
                },
            })
            this.chart1.axis('winSpd', {
                grid: null,
                label: {
                    style: {
                        fill: '#979ba4',
                    },
                },
                line: {
                    style: {
                        stroke: '#414959',
                    },
                },
            })
            this.chart1.tooltip({
                shared: true,
                showCrosshairs: true,
                domStyles: {
                    'g2-tooltip': {
                        background: 'rgba(0,0,0, 0.8)',
                        color: '#d6e0ec',
                    },
                },
            })
            this.chart1.line().position('date*winSpd').color('#4FAAEB')
            this.chart1.interaction('active-region')
            this.chart1.render()
        },
        reloadChart() {
            this.chartData = []
            this.chart1.changeData(this.chartData)
        },
        formatData(newData, type) {
            if (type == 1) {
                this.chartData.push(newData)
                if (this.chartData.length > 300) {
                    this.chartData.splice(0, 1)
                }
                this.chart1.changeData(this.chartData)
            } else if (type == 2) {
                this.chart2Data.push(newData)
                if (this.chart2Data.length > 300) {
                    this.chart2Data.splice(0, 1)
                }
                this.chart2.changeData(this.chart2Data)
            }
        },
        initChart2() {
            this.chart2 = new Chart({
                container: 'container2',
                autoFit: true,
                height: 300,
            })
            this.chart2.data(this.chart2Data)
            this.chart2.scale({
                date: {
                    alias: '时间',
                    type: 'time',
                    formatter: (value) => {
                        return utils.formatDate(value, 'time')
                    },
                },
                winD: {
                    alias: '风向',
                    sync: true, // 将 pv 字段数值同 time 字段数值进行同步
                    nice: true,
                    min: 0,
                },
            })
            this.chart2.axis('date', {
                grid: null,
                label: {
                    style: {
                        fill: '#979ba4',
                    },
                },
                line: {
                    style: {
                        stroke: '#414959',
                    },
                },
            })
            this.chart2.axis('winD', {
                grid: null,
                label: {
                    style: {
                        fill: '#979ba4',
                    },
                },
                line: {
                    style: {
                        stroke: '#414959',
                    },
                },
            })
            this.chart2.tooltip({
                shared: true,
                showCrosshairs: true,
                domStyles: {
                    'g2-tooltip': {
                        background: 'rgba(0,0,0, 0.8)',
                        color: '#d6e0ec',
                    },
                },
            })
            this.chart2.line().position('date*winD').color('#4FAAEB')
            this.chart2.interaction('active-region')
            this.chart2.render()
        },
        windowVisiable(e) {
            if (e.target.visibilityState == 'visible') {
                console.log('回到当前tab标签')
                this.reloadChart()
            } else {
                console.log('离开当前tab标签')
            }
        },
    },
}
</script>
<style lang="scss" scoped>
@import '@/assets/css/element-variables.scss';
// 背景颜色
$bgcolor: #effcff;
$font-color: rgb(78, 77, 77);
.page-container {
  display: flex;
}
.main-left {
  width: calc(55% - 10px);
  min-width: 480px;
  height: 100%;
  // display: flex;
  // flex-direction: column;
  // justify-content: space-between;
}
.main-right {
  margin-left: 10px;
  width: 45%;
  height: 100%;
  background-color: #fff;
}
.card1-1,
.card1-2,
.left-card2,
.left-card3 {
  // background-color: $bgcolor;
  background-color: rgba($--background-color-secondary, 0.7);
  border: 1px solid $--light-border;
  border-radius: 5px;
  
}
.card1-1,
.card1-2 {
  background: rgba(#20baf3, 0.7);
  border: none;
}
.left-card1 {
  height: 12%;
  // flex: 0 0 12%;
  min-height: 46px;
  margin-bottom: 10px;
  display: flex;
  justify-content: space-between;
}
.left-card2 {
  height: calc(38% - 10px);
  // flex: 0 0 38%;
  margin-bottom: 10px;
}
.left-card3 {
  height: calc(50% - 13px);
  // flex: 0 0 50%;
  /deep/ .el-image{
      width: 100%;
      height: 100%;
      border-radius: 5px;
  }
  /deep/ .el-image__placeholder,/deep/ .el-image__error {
    background: transparent;
  }
}

.card1-1 {
  width: calc(50% - 7px);
}
.card1-2 {
  width: calc(50% - 7px);
}
.icon_size {
  font-size: 36px;
  color: #03fae5;
}
.card1-content {
  display: flex;
  align-items: center;
  height: 100%;
  width: 80%;
  justify-content: center;
}
.font-style {
  font-size: 14px;
  font-weight: bold;
  color: $--color-text;
  padding: 0 10px;
}
.title-style {
  font-size: 14px;
  color: $--color-text;
  padding: 10px;
}

.left-card2{
    display: flex;
    .chart{
        width: 50%;
    }
}
#container1,
#container2 {
  height: calc(100% - 68px);
  width: calc(100% - 30px);
  padding: 15px;
}
// /deep/.el-table thead tr,
// /deep/.el-table thead tr th {
//   background-color: $--color-primary !important;
//   color: #fff;
// }
</style>
